********************************************************************************
*** Teacher Education Episodes and non-completion ******************************
* Graphical representation on the time of non-completion, dropout and switch   *
* events                                                                       *
********************************************************************************

*** Generate mean interview date in wave 2
nepsuse "CohortProfile", replace
keep ID_t wave tx8600y tx8600m
gen intdate2 = ym(tx8600y, tx8600m) if wave == 2
gen intdate4 = ym(tx8600y, tx8600m) if wave == 4
gen intdate6 = ym(tx8600y, tx8600m) if wave == 6
gen intdate8 = ym(tx8600y, tx8600m) if wave == 8

summarize intdate2, meanonly
local mean_value = round(r(mean))
gen intdate2_mean = `mean_value'

summarize intdate4, meanonly
local mean_value = round(r(mean))
gen intdate4_mean = `mean_value'

summarize intdate6, meanonly
local mean_value = round(r(mean))
gen intdate6_mean = `mean_value'

summarize intdate8, meanonly
local mean_value = round(r(mean))
gen intdate8_mean = `mean_value'

fre intdate2_mean intdate4_mean intdate6_mean intdate8_mean 

keep if wave ==2
keep ID_t intdate2 

save "${datasave}\intdate2.dta", replace

********************************************************************************
*** Load non-completion data
use "${datasave}/teacher_noncomp_wide.dta", clear

*** Generate date variable on events
gen noncompdate = enddate if noncompletion == 1
gen dropdate = enddate if dropout == 1
gen switchdate = enddate if switch == 1

gen noncompdate_bach = noncompdate if bachelor==1
gen noncompdate_stex = noncompdate if bachelor==0

gen dropdate_bach = dropdate if bachelor==1
gen dropdate_stex = dropdate if bachelor==0

gen switchdate_bach = switchdate if bachelor==1
gen switchdate_stex = switchdate if bachelor==0

fre noncompdate

*** Histogram Non-completion
* Overall
fre noncompdate
histogram noncompdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of non-completion date") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8)
graph export ${graphsave}/histo_noncomp.png, replace

* With line indicator of wave 2
histogram noncompdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) scheme(sj) ///	
	xaxis(1 2)	xline(622, lc(black) lw(thick)) xlabel(622 "Interviewdate year 1 (wave 2)", axis(2)) xtitle("",axis(2)) yscale(range(0 600))
graph export ${graphsave}/histo_noncomp_w2.png, replace

* Comparison between TEd degree
histogram noncompdate, xla(, format("%tm")) frequency ///
    title("Non-completion (full sample)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/nonall, replace)
histogram noncompdate_bach, xla(, format("%tm")) frequency ///
    title("Non-completion (Bachelor)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/nonba, replace)
histogram noncompdate_stex, xla(, format("%tm")) frequency ///
    title("Non-completion (State Examination)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/nonst, replace)
graph combine ${graphsave}/nonall.gph ${graphsave}/nonba.gph ${graphsave}/nonst.gph, plotregion(fcolor(grey)) rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/noncomp_bastex.png, replace




*** Histogram Dropout
*
fre dropdate
histogram dropdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of dropout date") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) 
graph export ${graphsave}/histo_drop.png, replace
* With line indicator of wave 2
histogram dropdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) ///	
	xaxis(1 2)	xline(622, lc(black) lw(thick)) xlabel(622 "Interviewdate Wave 2", axis(2)) xtitle("",axis(2))
graph export ${graphsave}/histo_drop_w2.png, replace

* Comparison between TEd degree
histogram dropdate, xla(, format("%tm")) frequency ///
    title("Dropout (full sample)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/dropall, replace)
histogram dropdate_bach, xla(, format("%tm")) frequency ///
    title("Dropout (Bachelor)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/dropba, replace)
histogram dropdate_stex, xla(, format("%tm")) frequency ///
    title("Dropout (State Examination)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/dropst, replace)
graph combine ${graphsave}/dropall.gph ${graphsave}/dropba.gph ${graphsave}/dropst.gph, plotregion(fcolor(grey)) rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/drop_bastex.png, replace


*** Histogram Switch
*
fre switchdate
histogram switchdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of switch date") ///
    xtitle("Date") ytitle("Frequency") ///
    xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
	legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) 
graph export ${graphsave}/histo_switch.png, replace
* With line indicator of wave 2
histogram switchdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) ///	
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
	xaxis(1 2)	xline(622, lc(black) lw(thick)) xlabel(622 "Interviewdate Wave 2", axis(2)) xtitle("",axis(2))
graph export ${graphsave}/histo_switch_w2.png, replace

* Comparison between TEd degree
histogram switchdate, xla(, format("%tm")) frequency ///
    title("Dropout (full sample)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/switchall, replace)
histogram switchdate_bach, xla(, format("%tm")) frequency ///
    title("Dropout (Bachelor)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/switchba, replace)
histogram switchdate_stex, xla(, format("%tm")) frequency ///
    title("Dropout (State Examination)") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/switchst, replace)
graph combine ${graphsave}/switchall.gph ${graphsave}/switchba.gph ${graphsave}/switchst.gph, plotregion(fcolor(grey)) rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/switch_bastex.png, replace



******************************
*** Combination of Histograms 
histogram noncompdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of non-completion date") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) yscale(range(0 600)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/a, replace)
histogram dropdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of dropout date") ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020", angle(45)) yscale(range(0 600)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/b, replace)
histogram switchdate, xla(, format("%tm")) frequency ///
    title("Frequency distribution of switch date") ///
    xtitle("Date") ytitle("Frequency") ///
    xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) yscale(range(0 600)) ///
	legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) saving(${graphsave}/c, replace)
graph combine ${graphsave}/a.gph ${graphsave}/b.gph ${graphsave}/c.gph, rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/histo_combination.png, replace

graph combine ${graphsave}/b.gph ${graphsave}/c.gph, rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/histo_combination_only2.png, replace

*** Combination of Histograms including Interviewdates
histogram noncompdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) ///	
	xaxis(1 2)	xline(622 634 646 658, lc(black) lw(thick)) xlabel(622 `" "Interview" "Wave 2" "' 634 `" "Interview" "Wave 4" "' 646 `" "Interview" "Wave 6" "' 658 `" "Interview" "Wave 8" "', axis(2) angle(45) labsize(2.5pt)) xtitle("",axis(2)) saving(${graphsave}/d, replace)
histogram dropdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) ///	
	xaxis(1 2)	xline(622 634 646 658, lc(black) lw(thick)) xlabel(622 `" "Interview" "Wave 2" "' 634 `" "Interview" "Wave 4" "' 646 `" "Interview" "Wave 6" "' 658 `" "Interview" "Wave 8" "', axis(2) angle(45) labsize(2.5pt)) xtitle("",axis(2)) saving(${graphsave}/e, replace)
histogram switchdate, xla(, format("%tm")) frequency ///
    xtitle("Date") ytitle("Frequency") ///
	xlabel(609 "10/2010" 615 "04/2011" 621 "10/2011" 627 "04/2012" 633 "10/2012" /// 
	639 "04/2013" 645 "10/2013" 651 "04/2014" 657 "10/2014" 663 "04/2015" 669 "10/2015" ///
	675 "04/2016" 681 "10/2016" 687 "04/2017" 693 "10/2017" 699 "04/2018" 705 "10/2018" ///
	712 "04/2019" 718 "10/2017" 724 "04/2020" 730 "10/2020", angle(45)) ///
    legend(off) plotregion(fcolor(white)) graphregion(fcolor(white)) color(gs8) ///	
	xaxis(1 2)	xline(622 634 646 658, lc(black) lw(thick)) xlabel(622 `" "Interview" "Wave 2" "' 634 `" "Interview" "Wave 4" "' 646 `" "Interview" "Wave 6" "' 658 `" "Interview" "Wave 8" "', axis(2) angle(45) labsize(2.5pt)) xtitle("",axis(2)) saving(${graphsave}/f, replace)
		
graph combine ${graphsave}/d.gph ${graphsave}/e.gph ${graphsave}/f.gph, plotregion(fcolor(grey)) rows(1) cols(3) xsize(12) ysize(4) scheme(sj)
graph export ${graphsave}/histo_combination_interview.png, replace




exit