********************************************************************************
*** Analysis  ****************************************************************
********************************************************************************

use "${datasave}/imputed_data_m20.dta", clear
 

**** FULL SAMPLE

log using "${logfiles}/analysis", replace

preserve
********************************************************************************
*** Listwise deletion FULL SAMPLE **********************************************
********************************************************************************
distinct ID_t
keep if _mi_miss == 0
distinct ID_t

mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust)
margins, dydx (*)

********************************************************************************
*** Listwise deletion RESTRICTED SAMPLE ****************************************
********************************************************************************
*** Persons with low Pensum (value = 1) and low grades (<= 3.5)
gen invol = 0
replace invol = 1 if (pensum==1 | grades>=3.5) & lastepi==1 
bys ID_t: egen involunt = max(invol)
distinct ID_t
drop if involunt==1
distinct ID_t

mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust)
margins, dydx (*) 

********************************************************************************
*** Imputation  FULL SAMPLE ********************************************
********************************************************************************
restore
distinct ID_t


mi estimate, post: mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust)
mimrgns, dydx (*) predict(default)

* FIT statistics
mi describe
local mtotal = r(M)
local r2 = 0
forvalues i = 1 / `mtotal' {
    quietly mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco if _mi_m == `i'
    local r2 = `r2' + e(r2_p)
}
di `r2' / `mtotal'


********************************************************************************
*** Imputation  RESTRICTED SAMPLE **************************************
********************************************************************************
*** Persons with low Pensum (value = 1) and low grades (<= 3.5)
gen invol = 0
replace invol = 1 if (pensum==1 | grades>=3.5) & lastepi==1 
bys ID_t: egen involunt = max(invol)
distinct ID_t
preserve
drop if involunt==1
distinct ID_t






* Descrete-time survival analysis
mi estimate, post: mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust)
* AME
*mimrgns, dydx (*) predict(default)
* odds ratio
mi estimate, rrr: mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust) nocons

* FIT statistics
mi describe
local mtotal = r(M)
local r2 = 0
forvalues i = 1 / `mtotal' {
    quietly mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco if _mi_m == `i'
    local r2 = `r2' + e(r2_p)
}
di `r2' / `mtotal'




* Sensitivity check
gen environment = pres + pract + course + lectur
* odds ratio
mi estimate, rrr: mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast environment acpe atvaprsu moco noco, vce(robust) nocons




*** Graphical representation of Results (German)
label define comprisk_lab 1 "Dropout" 2 "Switch"
label value comprisk comprisk_lab

mi estimate, rrr: mlogit comprisk i.female i.migra i.firstgen age i.bachelor_or ibn.wave inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco, vce(robust) nocons b(0)


*** Fit
coefplot (., keep(Dropout: inva soin utva)) (.,keep(Switch: inva soin utva)), ci eform xline(1) labels xtitle(Odds ratios (with 95% CIs)) xscale(log) ///
msymbol(d) title(Passung zum Studiengang) ///
coeflabel(inva = "Selbstwahrnehmung" ///
		  soin = "Soziales Interesse" ///
		  utva = "Zukünftige Ziele") ///
scheme(economist) levels(95) 
graph export ${graphsave}/passung_or.png, replace


*** Learn environment
coefplot (., keep(Dropout: fest fast pres pract course lectur)) (.,keep(Switch: fest fast pres pract course lectur)), ci eform xline(1) labels xtitle(Odds ratios (with 95% CIs)) xscale(log) ///
msymbol(d) title(Einfluss der Lernumwelt) ///
coeflabel(fest = "Soz. Int. (Studierende)" ///
		  fast = "Soz. Int. (Lehrende)"		 ///
		  pres = "Leistungsdruck" ///
		  pract = "Prakt. Orientierung" ///
		  course = "Koordination" ///
		  lectur = "Struktur") ///
scheme(economist) levels(95) 
graph export ${graphsave}/lernumwelt_or.png, replace

*** Achievement
coefplot (., keep(Dropout: acpe atvaprsu)) (.,keep(Switch: acpe atvaprsu)), ci eform xline(1) labels xtitle(Odds ratios (with 95% CIs)) xscale(log) ///
msymbol(d) title(Wahrgenommene Leistung) ///
coeflabel(acpe = "Subjektive Leistung" ///
		  atvaprsu = "Diff. Anspruch u. Leistung") ///
scheme(economist) levels(95) 
graph export ${graphsave}/leistung_or.png, replace

*** Individual preconditions
coefplot (., keep(Dropout: moco noco 1.firstgen)) (.,keep(Switch: moco noco 1.firstgen)), ci eform xline(1) labels xtitle(Odds ratios (with 95% CIs)) xscale(log) ///
msymbol(d) title(Individuelle Voraussetzung) ///
coeflabel(moco = "Finanz. Kosten" ///
		  noco = "Opportunitätskosten" ///
		  1.firstgen = "Bildungsherkunft") ///
scheme(economist) levels(95) 
graph export ${graphsave}/kosten_or.png, replace

restore

log close