********************************************************************************
*** sample for time-discrete analysis  *****************************************
********************************************************************************


*** define states per wave
nepsuse ID_t wave tx8600y tx8600m tx80220 using "CohortProfile", clear


* Interview dates
	bys ID_t: egen lastint = max(ym(tx8600y,tx8600m))
	lab var lastint "interviewdates in months since Jan 1960"
	bys ID_t: egen panelstatus=max(tx80220)
	lab val panelstatus de2468

	distinct ID_t
drop if lastint == . 
	distinct ID_t
	
	sort ID_t lastint
	by ID_t: gen lastepi = 1 if lastint == ym(tx8600y,tx8600m)

	gen intdate=ym(tx8600y,tx8600m)
	levelsof wave
	local waves `r(levels)'
	foreach wave of local waves {
		quietly: sum intdate if wave==`wave'
		local wavemean `r(mean)'
		replace intdate=round(`wavemean') if missing(intdate) & wave==`wave'
	}

	tab intdate, mis
	replace intdate = . if intdate > lastint

	foreach i of numlist 1/17 {
	gen intdate_wave`i' = intdate if wave==`i'
	bys ID_t: egen intdate`i'=min(intdate_wave`i')
	}

	tab intdate, mis

	drop intdate_wave*

	distinct ID_t
keep if lastepi == 1
	distinct ID_t

drop if tx80220==3
	distinct ID_t

	summarize intdate1 intdate2 intdate4 intdate6 intdate8 intdate10 lastint

keep ID_t intdate1-intdate17 lastint

save "${datasave}\intdates.dta", replace


*** merge with dropout events
merge 1:1 ID_t using "${datasave}\teacher_wide.dta", nogenerate keep(matched)
	distinct ID_t

order ID_t enddate intdate1-intdate17 	

	distinct ID_t
	* 5824

	
* marker for dropouts before wave 2 and after wave 10	
	gen noncomp_before2 = 1 if enddate < intdate2
	bys ID_t: egen before2 = max(noncomp_before2)
	
	distinct ID_t
drop if before2==1
	distinct ID_t
	
gen noncomp_after10 = 1 if enddate >= intdate10 & !missing(enddate)
	

	
* gen marker for noncompletion
	gen noncomp2 = 0
	replace noncomp2 = 1 if enddate >= intdate2 & enddate < intdate4 & noncompletion==1
	replace noncomp2 = . if lastint < intdate5  
	
	gen noncomp4 = 0
	replace noncomp4 = 1 if enddate >= intdate4 & enddate < intdate6 & noncompletion==1
	replace noncomp4 = . if lastint < intdate7 | noncomp2==1  

	gen noncomp6 = 0
	replace noncomp6 = 1 if enddate >= intdate6 & enddate < intdate8 & noncompletion==1
	replace noncomp6 = . if lastint < intdate9 | noncomp4==1  

	gen noncomp8 = 0
	replace noncomp8 = 1 if enddate >= intdate8 & enddate < intdate10 & noncompletion==1
	replace noncomp8 = . if lastint < intdate11 | noncomp6==1  

	
label variable noncomp2 "Non-completion between wave 2 and 4"
label variable noncomp4 "Non-completion between wave 4 and 6"
label variable noncomp6 "Non-completion between wave 6 and 8"
label variable noncomp8 "Non-completion after wave 8"

	
order ID_t enddate noncompletion lastint noncomp2 noncomp4 noncomp6 noncomp8
	
	fre noncomp2 noncomp4 noncomp6 noncomp8
	
* gen marker for dropout
	gen dropout2 = 0
	replace dropout2 = 1 if enddate >= intdate2 & enddate < intdate4 & dropout==1
	replace dropout2 = . if lastint < intdate5  

	gen dropout4 = 0
	replace dropout4 = 1 if enddate >= intdate4 & enddate < intdate6 & dropout==1
	replace dropout4 = . if lastint < intdate7 | dropout2==1  

	gen dropout6 = 0
	replace dropout6 = 1 if enddate >= intdate6 & enddate < intdate8 & dropout==1
	replace dropout6 = . if lastint < intdate9 | dropout4==1  

	gen dropout8 = 0
	replace dropout8 = 1 if enddate >= intdate8 & enddate < intdate10 & dropout==1
	replace dropout8 = . if lastint < intdate11 | dropout6==1  

	
label variable dropout2 "Dropout between wave 2 and 4"
label variable dropout4 "Dropout between wave 4 and 6"
label variable dropout6 "Dropout between wave 6 and 8"
label variable dropout8 "Dropout after wave 8"

	
order ID_t enddate dropout lastint dropout2 dropout4 dropout6 dropout8
	
	fre dropout2 dropout4 dropout6 dropout8	
	
* gen marker for switcher
	gen switch2 = 0
	replace switch2 = 1 if enddate >= intdate2 & enddate < intdate4 & switch==1
	replace switch2 = . if lastint < intdate5  

	gen switch4 = 0
	replace switch4 = 1 if enddate >= intdate4 & enddate < intdate6 & switch==1
	replace switch4 = . if lastint < intdate7 | switch2==1  

	gen switch6 = 0
	replace switch6 = 1 if enddate >= intdate6 & enddate < intdate8 & switch==1
	replace switch6 = . if lastint < intdate9 | switch4==1  

	gen switch8 = 0
	replace switch8 = 1 if enddate >= intdate8 & enddate < intdate10 & switch==1
	replace switch8 = . if lastint < intdate11 | switch6==1  

	
label variable switch2 "Switch between wave 2 and 4"
label variable switch4 "Switch between wave 4 and 6"
label variable switch6 "Switch between wave 6 and 8"
label variable switch8 "Switch after wave 8"




	
order ID_t enddate dropout* lastint switch*
	
fre switch2 switch4 switch6 switch8
	
	
***	
save "${datasave}\data_discrete.dta", replace	

exit
