********************************************************************************
*** Descriptives Predictors  ****************************************************
********************************************************************************


use "${datasave}\data_discrete.dta", clear
merge 1:1 ID_t using "${datasave}/pred_control.dta", keep(matched)
distinct ID_t

nepsmiss _all

drop wave

keep ID_t switch2 switch4 switch6 switch8 dropout2 dropout4 dropout6 dropout8 noncomp2 noncomp4 noncomp6 noncomp8 movesout2 movesout4 movesout6 movesout8 bachelor gpa math read female age migra hisei firstgen course22-read 

reshape long switch movesout dropout noncomp inva1 inva2 inva3 utva fest1 fest2 fest3 fast1 fast2 fast3 fast4 pres1 pres2 pres3 pract1 pract2 pract3 course1 course2 course3 lectur1 lectur2 lectur3 lectur4 acpe1 acpe2 acpe3 atva prsu moco mocodiff noco grades pensum ects, i(ID_t) j(wave)

foreach var of varlist inva1 inva2 inva3 utva fest1 fest2 fest3 fast1 fast2 fast3 fast4 pres1 pres2 pres3 pract1 pract2 pract3 course1 course2 course3 lectur1 lectur2 lectur3 lectur4 acpe1 acpe2 acpe3 atva prsu moco mocodiff noco grades pensum ects firstgen{
		replace `var'=. if `var' > .
}	

***** Dependend variable
*** Generate outcome variables
distinct ID_t
drop if noncomp==.
distinct ID_t
gen comprisk = 0 
replace comprisk = 1 if dropout == 1
replace comprisk = 2 if switch == 1 & movesout == 1

bys ID_t: egen lastwave = max(wave)
gen lastepi = 0
replace lastepi = 1 if lastwave==wave

***** Psychometric properties

*** Match with interests and self-perception
	* reverse item
	replace inva2 = 6-inva2
	
	* Enjoyment and identification
	sem(inva -> inva1 inva2 inva3), latent(inva) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict inva, latent
	replace inva=. if missing(inva1) & missing(inva2) & missing(inva3)
	bys wave: alpha inva1 inva2 inva3, detail
	lab var inva "Enjoyment and identification"

	* Interest
	sem(soin -> soin1 soin2 soin3), latent(soin) method(ml) standardized
	estat gof, stats(all)
	predict soin, latent
	replace soin=. if missing(soin1) & missing(soin2) & missing(soin3)
	bys wave: alpha soin1 soin2 soin3, detail
	lab var soin "Intrinsic value: Interest"	
	
	* Match with future goals
	tab utva
	
*** Influence of the learning environment
	* Social integration: Interaction with fellow students
	sem(fest -> fest1 fest2 fest3), latent(fest) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict fest, latent
	replace fest=. if missing(fest1) & missing(fest2) & missing(fest3)
	bys wave: alpha fest1 fest2 fest3, detail
	lab var fest "Peer soc. int."

	* Social integration: Interaction with faculty staff
	sem(fast -> fast1 fast2 fast3 fast4), latent(fast) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict fast, latent 
	replace fast=. if missing(fast1) & missing(fast2) & missing(fast3) & missing(fast4)
	bys wave: alpha fast1 fast2 fast3 fast4, detail  
	lab var fast "Facu. soc. int."		

preserve
drop if wave==4	
	
	* Pressure
	sem(pres -> pres1 pres2 pres3), latent(pres) group(wave) method(ml) standardized 
	estat gof, stats(all)
	predict pres, latent
	replace pres=. if missing(pres1) & missing(pres2) & missing(pres3)
	bys wave: alpha pres1 pres2 pres3, detail
	lab var pres "Pressure to perform"

	* Practical orientation
    sem(pract -> pract1 pract2 pract3), latent(pract) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict pract, latent
	replace pract=. if missing(pract1) & missing(pract2) & missing(pract3)
	bys wave: alpha pract1 pract2 pract3, detail
	lab var pract "Practical orientation"

	* Structure courses
	sem(course -> course1 course2 course3), latent(course) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict course, latent 
	replace course=. if missing(course1) & missing(course2) & missing(course3)
	bys wave: alpha course1 course2 course3, detail
	lab var course "Coordination of courses offered"

	* Structure lecturers
	bys wave: sem(lectur -> lectur1 lectur2 lectur3 lectur4), latent(lectur) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict lectur, latent 
	replace lectur=. if missing(lectur1) & missing(lectur2) & missing(lectur3) & missing(lectur4)
	bys wave: alpha lectur1 lectur2 lectur3 lectur4, detail
	lab var lectur "Structuredness of lectures and classes"

keep ID_t wave pres pract course lectur
tempfile studycond
save `studycond'
	
restore
merge 1:1 ID_t wave using "`studycond'", nogen keep(matched master)
	
*** PERCEIVED ACADEMIC PERFORMANCE
	* structural academic integraion
	sem(acpe -> acpe1 acpe2 acpe3), latent(acpe) group(wave) method(ml) standardized
	estat gof, stats(all)
	predict acpe, latent
	replace acpe=. if missing(acpe1) & missing(acpe2) & missing(acpe3)
	bys wave: alpha acpe1 acpe2 acpe3, detail  
	lab var acpe "Struct. acad. int."


	* Perceived mismatch between performance targets and actual performance
	tab atva, mis
	tab prsu, mis
	
	gen atvaprsu = atva-prsu
	tab atvaprsu
	
	
*** INDIVIDUAL PRECONDITIONS
	* financial costs
	tab moco
	tab mocodiff 
	* non-monetary costs
	tab noco
	* academic background
	tab firstgen
	
	

* Table 3: Descriptives of predictors
eststo wave2: estpost summarize inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco firstgen noncomp if wave==2
eststo wave4: estpost summarize inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco firstgen noncomp if wave==4
eststo wave6: estpost summarize inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco firstgen noncomp if wave==6
eststo wave8: estpost summarize inva soin utva fest fast pres pract course lectur acpe atvaprsu moco noco firstgen noncomp if wave==8

esttab wave2 wave4 wave6 wave8 using ${tabsave}/table3.rtf, replace main(mean %6.2f) aux(sd) mtitle("Year 1" "Year 2" "Year 3" "Year 4") nonumber nostar nogap  /// 
coeflabel(inva "Enjoyment and identification" soin "Social interest" utva "Match with future goals"  fest "Peer social integration" fast "Faculty social integration" pres "Study condition: pressure to perform" pract "Study condition: practical orientation" course "Study condition: Coordination of Study Program" lectur "Study condition: Structuredness of lectures" acpe "Struct. acad. integration" atvaprsu "ismatch between performance targets and actual performance" moco "Financial costs" noco "Non-monetary costs" firstgen "Academic background" noncomp "Non-completion") ///
title(Table 3. Descriptives of predictors) ///
nonotes addn(Standard deviations in parentheses.)

* Table 4: Correlation of predictors
spearman inva soin utva fest fast pres pract course lectur acpe atvaprsu moco mocodiff noco grades pensum ects
asdoc pwcorr inva soin utva fest fast pres pract course lectur acpe atvaprsu moco mocodiff noco grades pensum ects, label replace star(.05) dec(2) save(${tabsave}/table4_correlation.doc) title(Table 4. Correlation matrix of predictors)


*** Restrict data_discrete
keep ID_t wave comprisk lastepi inva soin utva fest fast pres pract course lectur acpe atvaprsu moco mocodiff noco grades pensum ects female migra firstgen age bachelor_or gpa

distinct ID_t
save "${datasave}\imputation_prep.dta", replace

