********************************************************************************
*** Follow-up activity of teacher education students ***************************
* Based on monthly split of episodes we look at follow-up activity of teacher  *
* education students who did not complete first teacher education episode 	   *
********************************************************************************
********************************************************************************
*** Events after study start  **************************************************
********************************************************************************
*** Step 1: Inflating, determining multiple months, cross laying ***
*** load and merge
use "${datasave}/teacher_noncomp_wide.dta", clear

merge 1:m ID_t using "${datapath}\SC5_Biography_D_18-0-0.dta", ///
 nogen keep(matched) 

	nepsmiss _all

	* check dates
	fre starty endy startm endm

	* gen start and end dates
	gen start = ym(starty,startm)
	gen end = ym(endy,endm)
	format start end %tm
	lab var start "Start date in months since Jan 1960"
	lab var end "End date in months since Jan 1960"

	* check duration
	gen dur = end-start+1
	sum dur, detail // keine negativen oder 0-Dauern vorhanden

	* delete variables
	drop wave splast-endy

	* Number of episode per person
	sort ID_t start end 
	by ID_t: gen epinr = [_n]
	lab var epinr "Episode number"
	fre epinr // maximal 53 Episoden pro Person

	* Inflating the data according to the duration of the episodes
	sort ID_t start end
	expand dur
	sort ID_t epinr

	* count month number
	by ID_t epinr: gen monnr = [_n]

	* Generate a monthly variable per month of a person's episode
	gen month = start+monnr-1

	* Delete redundant variables
	drop start end dur epinr monnr
	
	* count simultaneaous months
	* Within equal months is sorted first by module and then by spell number
	sort ID_t month sptype splink
	by ID_t month: gen monthnr = [_n]

	* check cases
	fre monthnr // maximum 8 same episodes, but hardly any cases with >2 episodes (less than 5%)
	drop monthnr

	*Information in multiple existing months is sorted in order to increase 
	*increase user-friendliness; sort order: 
	*a) main activities before secondary activities, 
	*b) episode types, which usually do not allow secondary activities, before others
	
	recode sptype 22=2 23=4 24=3 25=1 26=8 27=5 29=6 30=7 36=8 99=9, gen(spsort)
	sort ID_t month spms spsort splink 
	order ID_t month spms spsort splink 

	drop spsort
	by ID_t month: gen monthnr = [_n] 


	* if more than one activity per month -> use first month (see comment before for sorting)
	distinct ID_t
keep if monthnr==1
	distinct ID_t
	
	* keep only episodes after non-completion
	distinct ID_t
drop if month <= enddate
	distinct ID_t

	
*** Step 2: merge information from spell data sets ***
*** merge

	* generate variable for merge
	gen subspell = 0     

*** spelltype: voctrain ***
	merge m:1 ID_t splink subspell using "${datapath}\SC5_spVocTrain_D_18-0-0.dta", ///
	 nogen keep(1 3) keepusing(ts15221 ts15221_g1 tg24201 tg24170_g5 tg24173_g5 tg24176_g5 ts15291_g3 ts15218 ts15219 tg24202_g1 spell tg24159 tg24146 tg24159) 

	nepsmiss _all

*** Information about study program
nepsmiss ts15221_g1
clonevar graduation = ts15219
	
	clonevar aim_degree = ts15221_g1
	replace aim_degree = graduation if missing(aim_degree)
	lab var aim_degree "Study Program"

	* Bachelor 
	gen bachelor = .
	replace bachelor = 0 if !missing(aim_degree) & aim_degree >= 7
	replace bachelor = 1 if aim_degree == 12 | aim_degree == 13
	
	* Master
	gen master = .
	replace master = 0 if !missing(aim_degree) & aim_degree >= 7
	replace master = 1 if aim_degree == 14 | aim_degree == 15

	* State Examination
	gen stex = .
	replace stex = 0 if !missing(aim_degree) & aim_degree >= 7
	replace stex = 1 if aim_degree == 17 | aim_degree == 18

	* Teacher Education Program
	gen tedu = .
	replace tedu = 0 if !missing(aim_degree) & aim_degree >= 7
	replace tedu = 1 if inlist(aim_degree, 12, 14, 17)
	
	* Type of Teacher Education Program
	gen type = tg24202_g1
	replace type = tg24202_g1[_n-1] if type == -29 & ID_t[_n-1] == ID_t 
	lab var type "Type of Teacher Education"
	lab val type de3116ext1
	
	
	* Change of subject
	clonevar changesubject = tg24159
	
*** Vocational training
	gen vet = 0
	replace vet = 1 if inlist(ts15221_g1,1,2,3,4,5,6,24,25,26,27)
	
	* Other vocational training type
	gen others = 1 if inlist(ts15221_g1,19,20,21,22,28)
	
	* classification of jobs https://www.eurofound.europa.eu/surveys/ewcs/2005/classification
	gen collar = .
	replace collar=1 if inlist(int(ts15291_g3/1000),1,2,3)
	replace collar=2 if inlist(int(ts15291_g3/1000),4,5)
	replace collar=3 if inlist(int(ts15291_g3/1000),6,7)
	replace collar=4 if inlist(int(ts15291_g3/1000),8,9)
	
	label define coll 1 "high skilled white collar" 2 "low skilled white collar" 3 "high skilled blue collar" 4 "low skilled blue collar"
	label value collar coll
	
	tab vet collar, mis 
	tab ts15221_g1 if vet==1
	tab ts15221_g1 if vet==1 & collar==.
	
*** Status Variable
	gen status = 0
	replace status = 1 if tedu == 1 & status == 0
	replace status = 2 if tedu == 0 & status == 0
	replace status = 3 if vet == 1 & status == 0
	replace status = 4 if vet == 0 & status == 0 & !missing(collar)
	tab status others if sptype == 24, mis
	
drop ts15221 ts15221_g1 tg24201 tg24202_g1
 

*** spelltype: Employment ***
	merge m:1 ID_t splink subspell using "${datapath}\SC5_spEmp_D_18-0-0.dta", ///
	 nogen keep(1 3) keepusing(ts23203 ts23201_g3)
 
	nepsmiss _all
	
	* Employment
	gen emp = 0
	replace emp = 1 if sptype==26						   

	* employment type
	 recode ts23203 (1=1 "Arbeiter/in") (2=2 "Angestellte/r") (3=3 "Beamte/r") ///
	 (5=4 "Selbstaendige/r") (7=5 "Freie/r Mitarbeiter/in") ///
	 (8=6 "Ausbildungsbez. Taetigkeit") (9=7 "Referendariat") (4 6=8 "Sonstiges") (.b=.b "weiss nicht") ///
	 (.c=.c "verweigert"), gen(emptype)
	lab var emptype "Erwerbstyp"

	* classification of jobs https://www.eurofound.europa.eu/surveys/ewcs/2005/classification
	replace collar=1 if inlist(int(ts23201_g3/1000),1,2,3) & collar==.
	replace collar=2 if inlist(int(ts23201_g3/1000),4,5) & collar==.
	replace collar=3 if inlist(int(ts23201_g3/1000),6,7) & collar==.
	replace collar=4 if inlist(int(ts23201_g3/1000),8,9) & collar==.
	
	label value collar coll
	
	tab emptype, mis
	tab collar, mis
	tab emptype collar, mis
	
	drop ts23203 ts23201_g3
	 
*** Status Variable
	replace status = 4 if emp==1 & status == 0
	tab status others if sptype == 26, mis
	 

	
drop spell splink spms subspell ts15218 ts15219	

********************************************************************************
*** status variable  ***********************************************************
********************************************************************************
	
* label status variable	
	lab def stat 	1 "Teacher Education Program" ///
					2 "Other Study Program" ///
					3 "Vocational Training" ///
					4 "Employment" ///
					0 "NEET" 
	 
	lab value status stat

	tab status, mis

	sort ID_t month 
	
drop monthnr
	bys ID_t: gen monthnr = _n

	
	tab status if monthnr == 1, mis
	fre collar if emp==1 & monthnr == 1
	fre collar if vet==1 & monthnr == 1
	tab sptype if status==0 & monthnr == 1
	
	
compress	
********************************************************************************
*** save for sequence analysis  ************************************************
********************************************************************************
save "${datasave}\sequence_data.dta", replace

exit
