********************************************************************************
*** Imputation  ****************************************************************
********************************************************************************
use "${datasave}\imputation_prep.dta", clear

order ID_t wave female migra firstgen age bachelor_or gpa soin noco

reshape wide noco-atvaprsu, i(ID_t) j(wave)

order ID_t female migra age bachelor_or firstgen gpa soin comprisk2 comprisk4 comprisk6 comprisk8 lastepi2 lastepi4 lastepi6 lastepi8


drop ects*
drop mocodiff*


*** Are My Data MCAR, MAR, or MNAR?
unab numvars: age gpa soin comprisk2 comprisk4 comprisk6 comprisk8 lastepi2 lastepi4 lastepi6 lastepi8 noco2-atvaprsu8
unab missvars: gpa noco2-atvaprsu8



/*

foreach var of local missvars {
local covars: list numvars - var
display _newline(3) "logit missingness of `var' on `covars'"
logit miss_`var' `covars'
foreach nvar of local covars {
display _newline(3) "ttest of `nvar' by missingness of `var'"
ttest `nvar', by(miss_`var')
}
}

*/


drop miss*

replace comprisk4 = 4 if comprisk4==.
replace comprisk6 = 4 if comprisk6==.
replace comprisk8 = 4 if comprisk8==.

foreach var of varlist noco4 utva4 moco4 pensum4 grades4 inva4 fest4 fast4 acpe4 {
	replace `var' = 0 if comprisk4==4
}

foreach var of varlist noco6 utva6 moco6 pensum6 grades6 inva6 fest6 fast6 acpe6 pres6 pract6 course6 lectur6 atvaprsu6 {
	replace `var' = 0 if comprisk6==4
}


foreach var of varlist noco8 utva8 moco8 pensum8 grades8 inva8 fest8 fast8 acpe8 pres8 pract8 course8 lectur8 atvaprsu8 {
	replace `var' = 0 if comprisk8==4
}



* 
mi set flong
/* mi set mlong */

* 
mi register imputed firstgen gpa soin noco2-atvaprsu8
*
mi register regular female migra age bachelor_or comprisk*
*

mi impute chained /// 
/* impute time-constant variables */ ///
(pmm, knn(5)) soin gpa ///
(logit) firstgen ///
/* impute values in wave 2 */ ///
(ologit) noco2 utva2 moco2 pensum2 ///
(pmm, knn(5)) grades2 inva2 fest2 fast2 pres2 pract2 course2 lectur2 acpe2 atvaprsu2 ///
/* impute values in wave 4 only if not right-censored */ ///
(ologit, conditional(if comprisk4!=4)) noco4 utva4 moco4 pensum4 ///
(pmm, knn(5) conditional(if comprisk4!=4)) grades4 inva4 fest4 fast4 acpe4 ///
/* impute values in wave 6 only if not right-censored */ ///
(ologit, conditional(if comprisk6!=4)) noco6 utva6 moco6 pensum6 ///
(pmm, knn(5) conditional(if comprisk6!=4)) grades6 inva6 fest6 fast6 pres6 pract6 course6 lectur6 acpe6 atvaprsu6 ///
/* impute values in wave 8 only if not right-censored */ ///
(ologit, conditional(if comprisk8!=4)) noco8 utva8 moco8 pensum8 ///
(pmm, knn(5) conditional(if comprisk8!=4)) grades8 inva8 fest8 fast8 pres8 pract8 course8 lectur8 acpe8 atvaprsu8 ///
 = female migra age bachelor_or comprisk*, add(20) rseed(170698) savetrace(${logfiles}\tracefile, replace) dots augment orderasis 



* last observation carry forward
replace pres4 = pres2 
replace pract4 = pract2
replace course4 = course2
replace lectur4 = lectur2
replace atvaprsu4 = atvaprsu2
 
 
mi reshape long comprisk lastepi noco utva moco grades pensum inva fest fast pres pract course lectur acpe atvaprsu, i(ID_t) j(wave)
 
drop if comprisk==4
 
save "${datasave}/imputed_data_m20.dta", replace
 

 
* Check iterations
preserve
use ${logfiles}\tracefile, replace
reshape wide *mean *sd, i(iter) j(m)
tsset iter
tsline exp_mean*, title("Mean of Imputed Values of Experience") note("Each line is for one imputation") legend(off)
graph export conv1.png, replace
tsline exp_sd*, title("Standard Deviation of Imputed Values of Experience") note("Each line is for one imputation") legend(off)
graph export conv2.png, replace
restore



