********************************************************************************
*** Clean data for predictors and controls *************************************
********************************************************************************
nepsuse ID_t wave ///
tg53232 tg53234 tg53236 tg54121 ///
tg53121 tg53122 tg53123 tg53111 tg53112 tg53113 tg53114 t245401 t245402 t245403 ///
t246411 t246412 t246413 t243401 t243402 t243403 t243411 t243412 t243413 t243414 ///
tg53211 tg53212 tg53213 ///
tg54131 t300400 ///
t531006 tg54111 ///
tg52020 tg52030 tg52011 ///
 using "pTargetCAWI", clear

keep if wave == 2 | wave == 4  | wave == 6 | wave == 8	
nepsmiss _all

***** MATCH WITH STUDY PROGRAM *************************************************	
	*** Match with interests and self-perception
	* Commitment to degree course: enjoyment of degree program [from pTargetCAWI | wave 2, 4, 6, 8]
	rename tg53232 inva1
	* Commitment to degree course: don't enjoy degree course very much [from pTargetCAWI | wave 2, 4, 6, 8] 
	rename tg53234 inva2
	* Commitment to degree course: identification [from pTargetCAWI | wave 2, 4, 6, 8]
	rename tg53236 inva3
	
	*** Match with future goals
	* Target value: degree important intermediate step for life goals
	rename tg54121 utva
	
***** INFLUENCES OF THE LEARNING ENVIRONMENT ***********************************	
	*** Social integration (peers)
	* Social integration: able to establish contacts with students
	rename tg53121 fest1
	* Social integration: speak with classmates about questions in field of study
	rename tg53122 fest2
	* Social integration: many contacts with students
	rename tg53123 fest3
	
	*** Social integration (faculty)
	* Social integration: acceptance by instructors
	rename tg53111 fast1
	* Social integration: get along well with instructors
	rename tg53112 fast2
	* Social integration: fair treatment from instructors
	rename tg53113 fast3
	* Social integration: instructors interested
	rename tg53114 fast4
	
	**** Study conditions
	** Pressure to perform
		* High achievement norms
		rename t245401 pres1
		* Enough free time
		rename t245402 pres2
		* Heavy exam load
		rename t245403 pres3 
	** Practical orientation	
		* High practice orientation
		rename t246411 pract1
		* Promotion of professional competencies
		rename t246412 pract2
		* Close link between theory and practice
		rename t246413 pract3

	** Structure
	**Coordination of courses offered
		* SSCO: Structure of courses offered makes it possible to see the connections between them
		rename t243401 course1
		* SSCO: Good coordination of courses in terms of time
		rename t243402 course2
		* SSCO: Good coordination of courses in terms of content
		rename t243403 course3
	** Structuredness of lectures and classes
		* SSCO: clear definition of course learning objective
		rename t243411 lectur1
		* SSCO: Lecturers summarize periodically
		rename t243412 lectur2
		* SSCO: Lecturers establish links between sessions
		rename t243413 lectur3
		*SSCO: Teaching staff gives introductory overview of session
		rename t243414 lectur4
		
		
***** PERCEIVED ACADEMIC PERFORMANCE *******************************************	
	*** Structural academic integration
	* Academic performance: better than expected
	rename tg53211 acpe1
	* Academic performance: performance demands fulfilled
	rename tg53212 acpe2
	* Academic performance: satisfied with performance
	rename tg53213 acpe3
	
	
	*** Perceived mismatch between performance targets and actual performance
* ACHTUNG: Das funktioniert nur, wenn hier ein entsprechender Indikator als Differenz aus Wichtigkeit und tatsächlicher Performance rekodiert wird
	
	* tg54131 Personal importance of degree
	rename tg54131 atva
	* subjective probability of graduation
	rename t300400 prsu
		
***** INDIVIDUAL PRECONDITIONS *************************************************	
	*** Financial costs
	rename t531006 moco
	replace moco=6-moco
	* Change from the first measurement point
	gen moco1 = moco if wave==2
	bys ID_t: egen mocow1 = min(moco1)
	sort ID_t wave
	gen mocodiff = moco-mocow1 if wave > 2
	replace mocodiff = 0 if wave==2
	bys wave: sum mocodiff
	sort ID_t wave
	drop moco1 mocow1
	*** Oppoertunity costs
	rename tg54111 noco

	
	
***** CONTROLS *****************************************************************
	* Previouse achievement in study program
	rename tg52020 grades
	* study pensum 
	rename tg52030 pensum
	* ECTS
	rename tg52011 ects
	
		
reshape wide course2-mocodiff, i(ID_t) j(wave)

save "${datasave}/pred_new.dta", replace


********************************************************************************
********************************************************************************
********************************************************************************
nepsuse ID_t wave ///
t66207d t66207j t66207p ///
tg15001 tg15002 tg15003 tg15004 tg12003 ///
using "pTargetCATI", clear
	keep if wave == 1 

	
***** MATCH WITH STUDY PROGRAM *************************************************	
	*** Match with interests and self-perception
	* Social interest
	rename t66207d soin1
	rename t66207j soin2
	rename t66207p soin3
	
***** INDIVIDUAL PRECONDITIONS *************************************************
	* tg15001 Parents' opinion on degree course
	rename tg15001 parpro
	
	* Friends' opinion on degree course
	rename tg15002 peepro
	* Parents' opinion on subject
	rename tg15003 parsub
	* Opinion subject friends
	rename tg15004 peesub
	
*** Control
* Desired degree program fulfilled
	rename tg12003 desired_program
	
save "${datasave}/pred_new2.dta", replace
					
********************************************************************************
***************************CONTROLS*********************************************
********************************************************************************	
	
	
***************************** Competencies  ************************************

nepsuse ID_t res1_sc1 mas1_sc1 using "xTargetCompetencies", clear

	rename res1_sc1 read
	rename mas1_sc1 math
	
	nepsmiss _all
	
tempfile competence 	
save `competence'
	
	
************************ GPA in high school ************************************

nepsuse ID_t ts11211 ts11218 using "spSchool", clear

	keep if inlist(ts11211,1,2)

	by ID_t: gen spell= _n 	
	by ID_t: gen maxspell= _N 	
	keep if spell==maxspell

	replace ts11218=. if ts11218 > 4 
	
	nepsmiss ts11218
	
	gen gpa_rev = 5 - ts11218
	tab ts11218
	tab gpa_rev
	
	egen gpa = std(gpa_rev)
	lab var gpa "GPA school"

keep ID_t gpa
tempfile gpa 	
save `gpa'

*** merge data sets
merge 1:1 ID_t using "${datasave}/pred_new.dta", nogen
merge 1:1 ID_t using "${datasave}/pred_new2.dta", nogen
merge 1:1 ID_t using `competence', nogen
merge 1:1 ID_t using `gpa', nogen


save "${datasave}/pred_control.dta", replace