********************************************************************************
*** Initial Sample  ************************************************************
* All persons who indicate to study to become a teacher in the first wave which*
* is the PAPI/CATI in 2009/10 *
********************************************************************************

* load data
nepsuse using "spVocTrain", clear

keep if subspell == 0
distinct ID_t
keep if h_aktstu == 1
distinct ID_t

*** Information about study program
nepsmiss ts15221_g1
	clonevar graduation = ts15219
	
	clonevar aim_degree = ts15221_g1
	replace aim_degree = graduation if aim_degree==.
	lab var aim_degree "Study Program"

	* Bachelor 
	gen bachelor = .
	replace bachelor = 0 if !missing(aim_degree) & aim_degree >= 7
	replace bachelor = 1 if aim_degree == 12 | aim_degree == 13
	
	* Master
	gen master = .
	replace master = 0 if !missing(aim_degree) & aim_degree >= 7
	replace master = 1 if aim_degree == 14 | aim_degree == 15

	* State Examination
	gen stex = .
	replace stex = 0 if !missing(aim_degree) & aim_degree >= 7
	replace stex = 1 if aim_degree == 17 | aim_degree == 18

	* Teacher Education Program
	gen tedu = .
	replace tedu = 0 if !missing(aim_degree) & aim_degree >= 7
	replace tedu = 1 if inlist(aim_degree, 12, 14, 17)
	
	* Subject
	clonevar subject1 = tg24170_g2 
	clonevar subject2 = tg24173_g2 
	clonevar subject3 = tg24176_g2 

	* Type of Teacher Education Program
	gen type = tg24202_g1
	replace type = tg24202_g1[_n-1] if type == -29 & ID_t[_n-1] == ID_t 
	lab var type "Type of Teacher Education"
	lab val type de3116ext1

* Only teacher education students	
keep if tedu==1
		
	fre aim_degree bachelor master stex tedu subject1 subject2 subject3 type

keep ID_t aim_degree bachelor type subject1 subject2 subject3

* Save in temporary file for merging
tempfile sam 	
save `sam'


	
nepsuse using "Basics", clear
	
*** Sociodemographic
	* Sex
	gen female = 0 if t700001 == 2
	replace female = 1 if t700001 == 1
	lab var female "Sex (female)"
	label define lab2 0 "male" 1 "female" 
	label value female lab2

	* Migration
	gen migra = 0 if tx29005 == 1
	replace migra = 1 if tx29005 == 2 
	lab var migra "Migration background"
	label define lab3 0 "bron in Germany" 1 "born abroad" 
	label value migra lab3

	* HISEI
	egen hisei = rowmax(t731403_g14 t731453_g14)
	label value hisei lab3
	lab var hisei "HISEI (both parents)"

	* firstgen
	gen firstgen = 0 if t731301_g2 >= 0 | t731351_g2 >= 0
	replace firstgen = 1 if t731301_g2 >= 0 & t731301_g2 <= 6 & t731351_g2 >= 0 & t731351_g2 <= 6
	lab var firstgen "First generation student"
	label define lab4 0 "no first-generation student" 1 "first-generation student"
	label value firstgen lab4

	* Age
	gen age = 2009 - t70000y
	replace age = age - 1 if t70000m > 9
	lab var age "Age at study start (09/2009)"

keep ID_t female migra hisei firstgen age

*****
merge 1:1 ID_t using `sam', keep(matched) nogen
nepsmiss _all
*** Descriptives
tab type, gen(dum_type)

* Tables
estpost summarize age hisei firstgen migra female dum_type*
eststo summstats
esttab summstats using table2.rtf, replace main(mean %6.2f) aux(sd)

* Table 2
eststo summstats: estpost summarize age hisei firstgen migra female dum_type* bachelor
eststo bach: estpost summarize age hisei firstgen migra female dum_type* if bachelor==1
eststo nobach: estpost summarize age hisei firstgen migra female dum_type* if bachelor==0
esttab summstats bach nobach using "${tabsave}/table2.rtf", replace main(mean %6.2f) aux(sd) mtitle("Full sample" "Bachelor" "State Examination") nonumber nostar nogap ///
refcat(dum_type1 "School Type:", nolabel) ///
coeflabel(dum_type1 "Primary School" dum_type2 "Lower Secondary" dum_type3 "Upper Secondary" dum_type4 "Vocational School" dum_type5 "Special School" dum_type6 "Without Specification" age "Age" hisei "HISEI" firstgen "First generation student" migra "Not born in Germany" female "Female" bachelor "Bachelor") ///
title(Table 2. Sample description) ///
nonotes addn(Standard deviations in parentheses.)

rename bachelor bachelor_or
keep ID_t age hisei firstgen migra female bachelor_or
save "${datasave}/sample.dta", replace

exit