********************************************************************************
*** Sequence Analysis  *********************************************************
********************************************************************************
* load data
use "${datasave}\sequence_data.dta", clear

order ID_t monthnr month status

* Declare data for sequence analysis
	sqset status ID_t monthnr


*Sequence tables up to 6months
preserve

distinct ID_t
keep if monthnr<7
distinct ID_t

	sqtab
	sqtab, se
	asdoc 	sqtab, so save(${tabsave}/sequence_order_6months.doc) title(Order of sequences within 6 months after non-completion) fs(12) replace
	
	sqtab, so ranks(1/10)

	sqtab, ranks(1/10)

	sqindexplot
	graph export ${graphsave}\sqindexplot6months.png, replace

	
	sqparcoord, ylabel(1(1)4, valuelabel angle(0)) wlines(2)
	sqparcoord, so ranks(1/10) offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0))
	sqparcoord, so offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0)) scheme(sj)
	graph export ${graphsave}\sqparcoord_6months.png, replace

	sqom
	egen length1 = sqlength(), element(2)
	egen plotorder = group(_SQdist length1)
	sqindexplot, order(plotorder)
	sqindexplot	
	
restore	
	
*Sequence tables all observations
	sqtab
	sqtab, se
	asdoc 	sqtab, so save(${tabsave}/sequence_order_all_months.doc) title(Order of sequences within 6 months after non-completion) fs(12) replace
	
	sqtab, so ranks(1/10)

	sqtab, ranks(1/10)

	sqindexplot
	graph export ${graphsave}\sqindexplot_all_months.png, replace

	
	sqparcoord, ylabel(1(1)4, valuelabel angle(0)) wlines(2)
	sqparcoord, so ranks(1/10) offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0))
	sqparcoord, so offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0)) scheme(sj)
	graph export ${graphsave}\sqparcoord_allmonths.png, replace	
	

preserve


gen t=1 if monthnr==1 & status==1
bys ID_t: egen te = max(t)

drop if te==1
	
*Sequence tables if first after non-completion == teacher
	sqtab
	sqtab, se
	asdoc 	sqtab, so save(${tabsave}/sequence_order_teach.doc) title(Order of sequences after non-completion) fs(12) replace
	
	sqtab, so ranks(1/10)

	sqtab, ranks(1/10)

	sqindexplot, so saving(${graphsave}/b, replace) title("Sequence index plot with 'same order' similiarity") legend(position(3))
	graph export ${graphsave}\sqindexplot_teach_same_order.png, replace

	
	sqindexplot, saving(${graphsave}/a, replace) title("Sequence index plot") legend(off)
	graph export ${graphsave}\sqindexplot_teach.png, replace
	
	graph combine ${graphsave}/a.gph ${graphsave}/b.gph, plotregion(fcolor(grey)) rows(1) cols(2) xsize(12) ysize(6) 
	graph export ${graphsave}/sqindexplot_teach_combination.png, replace

	
	
	sqparcoord, ylabel(1(1)4, valuelabel angle(0)) wlines(2)
	sqparcoord, so ranks(1/10) offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0))
	sqparcoord, so offset(.5) wlines(1) ylabel(0(1)4, valuelabel angle(0)) scheme(sj)
	graph export ${graphsave}\sqparcoord_teach.png, replace
	
restore		


* Transition after leaving Teacher Education
distinct ID_t
keep if monthnr == 1
distinct ID_t

	fre status
	fre changesubj
	
	gen status2 = .
	replace status2 = 1 if status == 1
	replace status2 = 2 if status == 2 & changesubj == 1
	replace status2 = 3 if status == 2 & changesubj != 1
	replace status2 = 4 if status == 3
	replace status2 = 5 if status == 4
	replace status2 = 0 if status == 0
	
	lab def stat2 	1 "Teacher Education Program" ///
					2 "Other Study Program (same subject)" ///
					3 "Other Study Program (different subject)" ///
					4 "Vocational Training" ///
					5 "Employment" ///
					0 "NEET" 
	 
	lab value status2 stat2

	tab status status2, mis

	tab status
	fre status2
	
	graph pie, over(status) plabel(_all percent, format(%4.2f) color(white)) /// 
	pie(1, color(ebg)) pie(2, color(ebblue)) pie(3, color(edkblue)) pie(4, color(eltblue)) pie(5, color(eltgreen)) pie(6, color(emidblue)) ///
	title("Transition after leaving Teacher Education") ///
	legend(size(small)) ///
	sort descending scheme(sj) ///
	saving("${graphsave}\piechart_originate", replace)
	graph export ${graphsave}\piechart_originate.png, replace

	
	graph bar, over(status) /// 
	bar(1, color(ebg)) bar(2, color(ebblue)) bar(3, color(edkblue)) bar(4, color(eltblue)) bar(5, color(eltgreen)) bar(6, color(emidblue)) ///
	title("Transition after leaving Teacher Education") ///
	legend(size(small)) ///
	scheme(sj) ///
	saving("${graphsave}\piechart_originate", replace)
	graph export ${graphsave}\barchart_originate.png, replace
	
	tab collar status, column
	
* Transition after leaving Teacher Education after wave 2	
merge 1:1 ID_t using "${datasave}\intdate2.dta", ///
 nogen keep(matched) 
	
keep if month > intdate2

	fre status
	fre status2

	graph pie, over(status) plabel(_all percent, format(%4.2f) color(white)) /// 
	pie(1, color(ebg)) pie(2, color(ebblue)) pie(3, color(edkblue)) pie(4, color(eltblue)) pie(5, color(eltgreen)) pie(6, color(emidblue)) ///
	title("Transition after leaving Teacher Education after wave 2") ///
	legend(size(small)) ///
	sort descending scheme(sj) ///
	saving("${graphsave}\piechart_originate", replace)
	graph export ${graphsave}\piechart_originate_wave2.png, replace	
	
exit


