********************************************************************************
*** Teacher Education Episodes and non-completion ******************************
* Based on the initial sample, we look at the study episodes of teacher edu.   *
* students. Furthermore, we identify non-completion events and switches into   *
* other study programs.                                                        *
********************************************************************************

nepsuse using "spVocTrain", clear
merge m:1 ID_t using "${datasave}/sample.dta", nogen keep(matched)

keep if subspell == 0

*** Information about episodes
	gen startdate=ym(ts1511y,ts1511m)
	gen enddate=ym(ts1512y,ts1512m)
	gen duration = enddate-startdate+1
		
	* Graduation
	clonevar graduation = ts15219
	
	gen success = 0 if ts15218==2
	replace success = 1 if ts15218==1
	lab var success "Graduation of episode (yes/no)"
	
	* Switch
	* switch subject1
	sort ID_t spell
	gen changesubj = .
	replace changesubj = tg24159[_n+1] if spell+1==spell[_n+1] & ID_t==ID_t[_n+1]
	gen changeprog = .
	replace changeprog = tg24146[_n+1] if spell+1==spell[_n+1] & ID_t==ID_t[_n+1]
	gen changeHEI = .
	replace changeHEI  = tg24121[_n+1] if spell+1==spell[_n+1] & ID_t==ID_t[_n+1]
	
	lab var changesubj "Change of Subject (to next episode)"
	lab var changeprog "Change of Study Program (to next episode)"
	lab var changeHEI "Change of HEI (to next episode)"

	
	lab val changesubj de1859ext1
	lab val changeprog de1860ext1
	lab val changeHEI de2721ext1
	
	order ID_t  spell tg24159 changesubj success
	
	* andauern der Episodes
	clonevar rightcensored = ts1512c
	lab var rightcensored "Episode still ongoing"

	
*** Delete episodes that started before winter term 2010/11 (September 2010)
	drop if h_aktstu==2

*** Information about Study Episodes
	* Degree Type
nepsmiss ts15221_g1
	clonevar aim_degree = ts15221_g1
	replace aim_degree = graduation if aim_degree==.
	lab var aim_degree "Study Program"
	
	* Bachelor 
	gen bachelor = .
	replace bachelor = 0 if !missing(aim_degree) & aim_degree >= 7
	replace bachelor = 1 if aim_degree == 12 | aim_degree == 13
	
	* Master
	gen master = .
	replace master = 0 if !missing(aim_degree) & aim_degree >= 7
	replace master = 1 if aim_degree == 14 | aim_degree == 15

	* State Examination
	gen stex = .
	replace stex = 0 if !missing(aim_degree) & aim_degree >= 7
	replace stex = 1 if aim_degree == 17 | aim_degree == 18

	* Teacher Education Program
	gen tedu = .
	replace tedu = 0 if !missing(aim_degree) & aim_degree >= 7
	replace tedu = 1 if inlist(aim_degree, 12, 14, 17)
	
	* Subject
	clonevar subject1 = tg24170_g2 
	clonevar subject2 = tg24173_g2 
	clonevar subject3 = tg24176_g2 

	* Type of Teacher Education Program
	gen type = tg24202_g1
	replace type = tg24202_g1[_n-1] if type == -29 & ID_t[_n-1] == ID_t 
	lab var type "Type of Teacher Education"
	lab val type de3116ext1
	
	* HEI
	clonevar HEI = ID_i
	
***
nepsmiss _all	
	
	
*** Generate Noncompletion Variable
* Noncompletion = 0 if episode was successfully graduated 
* Nocompletion = 1 if episode was not successful	
	gen noncompletion = .
	replace noncompletion = 0 if success == 1 | rightcensored == 1
	replace noncompletion = 1 if success != 1 & rightcensored !=1
	lab var noncompletion "Non-completion of episode"
	
	
order ID_t	noncompletion  changeprog changesubj changeHEI success rightcensored

* Correction: if only HEI change -> do not count as non-completion
	gen help_HEI = 0
	replace help_HEI = 1 if changeHEI==2 & changeprog==1 & changesubj==1 & success==0
	tab help_HEI noncompletion
	replace enddate = enddate[_n+1] if ID_t==ID_t[_n+1] & help_HEI == 1
	
drop help_HEI

distinct ID_t
tab h_aktstu noncompletion, mis

drop if missing(noncompletion)
distinct ID_t
* Dropout
	gen dropout = noncompletion
	replace dropout = 0 if !missing(changeprog) | !missing(changesubj)
	lab var dropout "Dropout"
	
	gen switch = noncompletion
	replace switch = 0 if missing(changeprog) & missing(changesubj)
	lab var switch "Change of Study Program"
	
	gen movesout = switch
	replace movesout = 0 if switch == 1 & tedu[_n+1]==1 & ID_t==ID_t[_n+1]
	lab var movesout "Change into Non-teaching"

	
sort ID_t startdate enddate
	
tab dropout switch, mis
tab dropout noncompletion, mis
tab switch noncompletion, mis

order ID_t startdate enddate noncompletion dropout switch changeprog changesubj changeHEI success rightcensored aim_degree

keep ID_t startdate enddate noncompletion dropout switch movesout changeprog changesubj  changeHEI success rightcensored female migra hisei firstgen age bachelor_or h_aktstu

*** Save Long Format
save "${datasave}/teacher_long.dta", replace

*** Generate Wide Sample
	distinct ID_t
keep if h_aktstu==1
	distinct ID_t
drop h_aktstu
	
** Save Wide Format	
save "${datasave}/teacher_wide.dta", replace

tab noncompletion
tab dropout
tab switch
tab movesout

*** Save Non-completion Cases	
keep if noncompletion == 1


save "${datasave}/teacher_noncomp_wide.dta", replace

